<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:tdm="http://www.quest.com/toad-data-modeler" xmlns:msxsl="urn:schemas-microsoft-com:xslt">
	<tdm:description>Output contains Entity Name, Caption, Comments and Attribute Name, Caption, Data Type, Data Type Parameters, Key and Not null specifications and Comments. You can change List Separator. Click MORE and change value in the Parameter Value column.</tdm:description>
	<tdm:caption>Entities and Attributes (CSV)</tdm:caption>
	<tdm:default-filename>entities-attributes</tdm:default-filename>
	<tdm:default-suffix>csv</tdm:default-suffix>
	<tdm:db-platforms>
		<tdm:db-platform>all</tdm:db-platform>
	</tdm:db-platforms>

	<msxsl:script language="JScript" implements-prefix="tdm">
		function closeInApostrophes( nodelist ) {
		var text = nodelist.nextNode().text;
		return( '"' + text.replace( /\"/g, '""' ) + '"' );
		}
	</msxsl:script>

	<xsl:output method="text" />
	<xsl:param name="ListSeparator" select="," />
	<xsl:template match="/">

		<xsl:for-each select="Model/Entities/Entity">
			<xsl:sort select="Name" />
			<xsl:if test="position() = 1">
				<xsl:text>Entity Name</xsl:text>
				<xsl:value-of select="$ListSeparator" />
				<xsl:text>Entity Caption</xsl:text>
				<xsl:value-of select="$ListSeparator" />
				<xsl:text>Entity Description</xsl:text>
				<xsl:value-of select="$ListSeparator" />
				<xsl:text>Attribute Name</xsl:text>
				<xsl:value-of select="$ListSeparator" />
				<xsl:text>Attribute Caption</xsl:text>

				<xsl:value-of select="$ListSeparator" />
				<xsl:text>Data Type</xsl:text>

				<xsl:value-of select="$ListSeparator" />
				<xsl:text>Param 1</xsl:text>

				<xsl:value-of select="$ListSeparator" />
				<xsl:text>Param 2</xsl:text>

				<xsl:value-of select="$ListSeparator" />
				<xsl:text>Key (PK/PFK/AK/FK)</xsl:text>

				<xsl:value-of select="$ListSeparator" />
				<xsl:text>Not Null</xsl:text>

				<xsl:value-of select="$ListSeparator" />
				<xsl:text>Attribute Description</xsl:text>
				<xsl:text>&#10;</xsl:text>
			</xsl:if>
			<xsl:variable name="eName" value="">
				<xsl:value-of select="tdm:closeInApostrophes(Name)" />
			</xsl:variable>
			<xsl:variable name="eCap" value="">
				<xsl:value-of select="tdm:closeInApostrophes(Caption)" />
			</xsl:variable>
			<xsl:variable name="eCom" value="">
				<xsl:if test="(Comments)!=''">
					<xsl:value-of select="tdm:closeInApostrophes(Comments)" />
				</xsl:if>
			</xsl:variable>
			<xsl:for-each select="Attributes/Attribute">
				<xsl:value-of select="$eName" />
				<xsl:value-of select="$ListSeparator" />
				<xsl:value-of select="$eCap" />
				<xsl:value-of select="$ListSeparator" />
				<xsl:value-of select="$eCom" />
				<xsl:value-of select="$ListSeparator" />
				<xsl:value-of select="tdm:closeInApostrophes(Name)" />
				<xsl:value-of select="$ListSeparator" />
				<xsl:value-of select="tdm:closeInApostrophes(Caption)" />
				<xsl:value-of select="$ListSeparator" />
				<xsl:choose>
					<xsl:when test="string-length(DataType/Name)>0">
						<xsl:value-of select="tdm:closeInApostrophes(DataType/Name)" />
						<xsl:value-of select="$ListSeparator" />
						<xsl:value-of select="tdm:closeInApostrophes(DataType/Param1)" />
						<xsl:value-of select="$ListSeparator" />
						<xsl:value-of select="tdm:closeInApostrophes(DataType/Param2)" />
					</xsl:when>
					<xsl:when test="string-length(Domain/Name)>0">
						<xsl:call-template name="DomainDetails">
							<xsl:with-param name="domainid" select="Domain/Id" />
						</xsl:call-template>
					</xsl:when>
					<xsl:when test="string-length(UserDataType/Name)>0">
						<xsl:value-of select="tdm:closeInApostrophes(UserDataType/Name)" />
						<xsl:value-of select="$ListSeparator" />
						<xsl:value-of select="$ListSeparator" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:text disable-output-escaping="yes">?</xsl:text>
					</xsl:otherwise>
				</xsl:choose>

				<xsl:value-of select="$ListSeparator" />
				<xsl:if test="string-length(KeyItems/ReferencedObject/Name)>0 or string-length(ForeignOtherKeys/ReferencedObject/Name)>0">
					<xsl:text>Yes</xsl:text>
				</xsl:if>
				
				<xsl:value-of select="$ListSeparator" />
				<xsl:call-template name="BooleanToText">
					<xsl:with-param name="PassedValue" select="NotNull" />
				</xsl:call-template>
				
				<xsl:value-of select="$ListSeparator" />
				<xsl:if test="(Comments)!=''">
					<xsl:value-of select="tdm:closeInApostrophes(Comments)" />
				</xsl:if>
				<xsl:text>&#10;</xsl:text>
			</xsl:for-each>
		</xsl:for-each>
	</xsl:template>

	<xsl:template name="DomainDetails">
		<xsl:param name="domainid" />
		<xsl:for-each select="/Model/Domains/Domain">
			<xsl:if test="Id=$domainid">
				<xsl:value-of select="tdm:closeInApostrophes(DataType/Name)" />
				<xsl:value-of select="$ListSeparator" />
				<xsl:value-of select="tdm:closeInApostrophes(DataType/Param1)" />
				<xsl:value-of select="$ListSeparator" />
				<xsl:value-of select="tdm:closeInApostrophes(DataType/Param2)" />
			</xsl:if>
		</xsl:for-each>
	</xsl:template>

	<xsl:template name="BooleanToText">
		<xsl:param name="PassedValue" />
		<xsl:choose>
			<xsl:when test="$PassedValue = 1">
				<xsl:text>Yes</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>No</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>
